swh-graph-stdlib 14.0.0

Library of algorithms and data structures for swh-graph
docs.rs failed to build swh-graph-stdlib-14.0.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: swh-graph-stdlib-13.2.0

Standard library to work on Software Heritage compressed graph in Rust