ls_tree

Function ls_tree 

pub fn ls_tree<G>(graph: &G, dir: NodeId) -> Result<FsTree>
Given a graph and a directory node in it (usually, but not necessarily, the root directory of a repository), return a recursive list of the contained files and directories.

Note that symlinks are not followed during listing and are reported as files in the returned tree. To recognize them as links, check the permissions of the associated directory entries.