Module labeling

Module labeling 

Associate information to a subset of nodes

Structs

BoxLabel
Helper for SliceLabel
DenseLabels
MapReduce
Associates labels to nodes in the graph using successor nodes’ labels and “bubbling up”
MapReduceBuilder
Builder for MapReduce
SliceLabel
Implementation of StridableLabel that simply wraps a slice.
SparseLabels
StriddenLabels
StriddenLabelsConfig

Traits

Labels
MapReducer
Callbacks for MapReduce
StridableLabel
A Label that is a view over a slice of an array