#[repr(transparent)]pub struct BoxLabel<Word: AnyBitPattern>(pub Box<[Word]>);Expand description
Helper for SliceLabel
Tuple Fields
0: Box<[Word]>Trait Implementations
Sourceimpl<Word: AnyBitPattern> Borrow<SliceLabel<Word>> for BoxLabel<Word>
impl<Word: AnyBitPattern> Borrow<SliceLabel<Word>> for BoxLabel<Word>
Sourcefn borrow(&self) -> &SliceLabel<Word>
fn borrow(&self) -> &SliceLabel<Word>
Immutably borrows from an owned value. Read more
Sourceimpl<Word: AnyBitPattern> BorrowMut<SliceLabel<Word>> for BoxLabel<Word>
impl<Word: AnyBitPattern> BorrowMut<SliceLabel<Word>> for BoxLabel<Word>
Sourcefn borrow_mut(&mut self) -> &mut SliceLabel<Word>
fn borrow_mut(&mut self) -> &mut SliceLabel<Word>
Mutably borrows from an owned value. Read more
Sourceimpl<Word: AnyBitPattern> TransparentWrapper<Box<[Word]>> for BoxLabel<Word>
impl<Word: AnyBitPattern> TransparentWrapper<Box<[Word]>> for BoxLabel<Word>
Sourcefn wrap_ref(s: &Inner) -> &Self
fn wrap_ref(s: &Inner) -> &Self
Convert a reference to the inner type into a reference to the wrapper
type.
Sourcefn wrap_mut(s: &mut Inner) -> &mut Self
fn wrap_mut(s: &mut Inner) -> &mut Self
Convert a mutable reference to the inner type into a mutable reference to
the wrapper type.
Sourcefn wrap_slice(s: &[Inner]) -> &[Self]where
Self: Sized,
fn wrap_slice(s: &[Inner]) -> &[Self]where
Self: Sized,
Convert a slice to the inner type into a slice to the wrapper type.
Sourcefn wrap_slice_mut(s: &mut [Inner]) -> &mut [Self]where
Self: Sized,
fn wrap_slice_mut(s: &mut [Inner]) -> &mut [Self]where
Self: Sized,
Convert a mutable slice to the inner type into a mutable slice to the
wrapper type.
Sourcefn peel_ref(s: &Self) -> &Inner
fn peel_ref(s: &Self) -> &Inner
Convert a reference to the wrapper type into a reference to the inner
type.
Sourcefn peel_mut(s: &mut Self) -> &mut Inner
fn peel_mut(s: &mut Self) -> &mut Inner
Convert a mutable reference to the wrapper type into a mutable reference
to the inner type.
Sourcefn peel_slice(s: &[Self]) -> &[Inner]where
Self: Sized,
fn peel_slice(s: &[Self]) -> &[Inner]where
Self: Sized,
Convert a slice to the wrapped type into a slice to the inner type.
Sourcefn peel_slice_mut(s: &mut [Self]) -> &mut [Inner]where
Self: Sized,
fn peel_slice_mut(s: &mut [Self]) -> &mut [Inner]where
Self: Sized,
Convert a mutable slice to the wrapped type into a mutable slice to the
inner type.
impl<Word: Eq + AnyBitPattern> Eq for BoxLabel<Word>
impl<Word: AnyBitPattern> StructuralPartialEq for BoxLabel<Word>