pub struct MapReduce<G: SwhForwardGraph + SwhBackwardGraph, MR: MapReducer, L> {
pub map_reducer: MR,
/* private fields */
}Expand description
Associates labels to nodes in the graph using successor nodes’ labels and “bubbling up”
Use swh_graph::views::Subgraph to select the set of nodes to run this on.
For example, to avoid content and directory nodes (which are typically much slower to process),
use Subgraph::with_node_constraint("rev,rel,snp,ori".parse().unwrap()).
Built from MapReduceBuilder
Example
For example, with this graph:
- 3
/
<-
1 <--- 4 <--+
+--- 6
2 <--- 5 <--+We call 1 a successor of 3, consistent with swh-graph’s terminology, even though MapReducer propagates labels in the other direction.
we would:
- compute label of 1
- compute label of 2
- compute label of 2 and merge it with 1’s
- compute label of 4 and merge it with 1’s
- compute label of 5 and merge it with 2’s
- compute label of 6 and merge it with 4’s and 5’s
Fields
map_reducer: MRImplementations
Sourceimpl<G: SwhForwardGraph + SwhBackwardGraph, MR: MapReducer, L: Labels<Label = MR::Label>> MapReduce<G, MR, L>
impl<G: SwhForwardGraph + SwhBackwardGraph, MR: MapReducer, L: Labels<Label = MR::Label>> MapReduce<G, MR, L>
Sourcepub fn run_in_topological_order(
&mut self,
nodes: impl Iterator<Item = NodeId>,
) -> Result<(), MR::Error>
pub fn run_in_topological_order( &mut self, nodes: impl Iterator<Item = NodeId>, ) -> Result<(), MR::Error>
Runs the configured MapReducer sequentially on all nodes in the graph.
nodes must be an iterator of all nodes in topological order,
eg. returned by GenerationsReader::iter_nodes
with .map(|(_depth, node)| node).
Sourcepub fn push_node(&mut self, node: NodeId) -> Result<(), MR::Error>
pub fn push_node(&mut self, node: NodeId) -> Result<(), MR::Error>
A single step of Self::run_in_topological_order, in case the caller does not have an
iterator of nodes
Sourcepub fn labels(&self) -> Result<&L>
pub fn labels(&self) -> Result<&L>
Returns every node’s labels, if MapReduceBuilder::keep_labels was set to true.
Sourcepub fn take_labels(self) -> Result<L>
pub fn take_labels(self) -> Result<L>
Returns every node’s labels, if MapReduceBuilder::keep_labels was set to true.