#[repr(transparent)]pub struct SliceLabel<Word: AnyBitPattern>(pub [Word]);Expand description
Implementation of StridableLabel that simply wraps a slice.
Tuple Fields
0: [Word]Trait Implementations
Sourceimpl<Word: AnyBitPattern> AsMut<[Word]> for SliceLabel<Word>
impl<Word: AnyBitPattern> AsMut<[Word]> for SliceLabel<Word>
Sourceimpl<Word: AnyBitPattern> AsRef<[Word]> for SliceLabel<Word>
impl<Word: AnyBitPattern> AsRef<[Word]> for SliceLabel<Word>
Sourceimpl<Word: AnyBitPattern> Borrow<SliceLabel<Word>> for BoxLabel<Word>
impl<Word: AnyBitPattern> Borrow<SliceLabel<Word>> for BoxLabel<Word>
Sourcefn borrow(&self) -> &SliceLabel<Word>
fn borrow(&self) -> &SliceLabel<Word>
Immutably borrows from an owned value. Read more
Sourceimpl<Word: AnyBitPattern> BorrowMut<SliceLabel<Word>> for BoxLabel<Word>
impl<Word: AnyBitPattern> BorrowMut<SliceLabel<Word>> for BoxLabel<Word>
Sourcefn borrow_mut(&mut self) -> &mut SliceLabel<Word>
fn borrow_mut(&mut self) -> &mut SliceLabel<Word>
Mutably borrows from an owned value. Read more
Sourceimpl<Word: Debug + AnyBitPattern> Debug for SliceLabel<Word>
impl<Word: Debug + AnyBitPattern> Debug for SliceLabel<Word>
Sourceimpl<Word: PartialEq + AnyBitPattern> PartialEq for SliceLabel<Word>
impl<Word: PartialEq + AnyBitPattern> PartialEq for SliceLabel<Word>
Sourceimpl<Word: AnyBitPattern + Default> StridableLabel for SliceLabel<Word>
impl<Word: AnyBitPattern + Default> StridableLabel for SliceLabel<Word>
Sourceimpl<Word: AnyBitPattern> ToOwned for SliceLabel<Word>
impl<Word: AnyBitPattern> ToOwned for SliceLabel<Word>
Sourceimpl<Word: AnyBitPattern> TransparentWrapper<[Word]> for SliceLabel<Word>
impl<Word: AnyBitPattern> TransparentWrapper<[Word]> for SliceLabel<Word>
Sourcefn wrap_ref(s: &Inner) -> &Self
fn wrap_ref(s: &Inner) -> &Self
Convert a reference to the inner type into a reference to the wrapper
type.
Sourcefn wrap_mut(s: &mut Inner) -> &mut Self
fn wrap_mut(s: &mut Inner) -> &mut Self
Convert a mutable reference to the inner type into a mutable reference to
the wrapper type.
Sourcefn peel_ref(s: &Self) -> &Inner
fn peel_ref(s: &Self) -> &Inner
Convert a reference to the wrapper type into a reference to the inner
type.
Sourcefn peel_mut(s: &mut Self) -> &mut Inner
fn peel_mut(s: &mut Self) -> &mut Inner
Convert a mutable reference to the wrapper type into a mutable reference
to the inner type.
impl<Word: Eq + AnyBitPattern> Eq for SliceLabel<Word>
impl<Word: AnyBitPattern> StructuralPartialEq for SliceLabel<Word>