pub struct StriddenLabels<Label: StridableLabel + ?Sized> { /* private fields */ }Implementations
Sourceimpl<Label: StridableLabel + ?Sized> StriddenLabels<Label>
impl<Label: StridableLabel + ?Sized> StriddenLabels<Label>
Sourcepub fn iter(&self) -> impl Iterator<Item = Option<&Label>>
pub fn iter(&self) -> impl Iterator<Item = Option<&Label>>
Returns an iterator with the label of each node, if any
Sourcepub fn iter_labeled(&self) -> impl Iterator<Item = (NodeId, &Label)>
pub fn iter_labeled(&self) -> impl Iterator<Item = (NodeId, &Label)>
Returns an iterator with each labeled node
Sourcepub fn par_iter(&self) -> impl ParallelIterator<Item = Option<&Label>>
pub fn par_iter(&self) -> impl ParallelIterator<Item = Option<&Label>>
Returns a parallel iterator with the label of each node, if any
Sourcepub fn par_iter_labeled(&self) -> impl ParallelIterator<Item = (NodeId, &Label)>
pub fn par_iter_labeled(&self) -> impl ParallelIterator<Item = (NodeId, &Label)>
Returns a parallel iterator with each labeled node