pub struct SortedSlice<Item: Ord, S: AsRef<[Item]> + ?Sized> {
pub marker: PhantomData<Item>,
pub slice: S,
}Expand description
A slice of NodeId whose values are in ascending order
Safety
Unsafe code should not rely on this to be sorted, as safe code can build arbitrary instances
Fields
marker: PhantomData<Item>slice: SImplementations