Functionalities related to managing software origins in the Software Heritage graph.
Software origins (origins for short) represent places used to develop and distribute software
source code, such as version control system repositories and (source) package repositories.
Origins are represented in the Software Heritage graph as nodes with type NodeType::Origin.
Statics
- PROTOCOL_
RE - Regular expression matching any URI/URL protocol prefix, e.g., “http://”.
Functions
- fuzzy_
find_ origins - Search if a given set of origins, specified by URL, exist in the graph.
- normalize_
origin_ url - Normalize an origin URL to a canonical origin identifier.