Version control system (VCS) functions.
Constants
- HEAD_
REF_ NAMES - Names of references (“branches”) that are considered to be pointing to the HEAD revision in a VCS, by find_head_rev below. Names are tried in order, when attempting to identify the HEAD revision.
Functions
- find_
head_ rev - Given a graph and a snapshot node in it, return the node id of the revision pointed by the HEAD branch, it it exists.
- find_
head_ rev_ by_ refs - Same as find_head_rev, but with the ability to configure which branch names correspond to the HEAD revision.
- list_
root_ revisions - Returns all revisions that have no parent revision.