Module vcs

Module vcs 

Version control system (VCS) functions.

Structs

RevListOptions
Revision listing options (for list_revisions_with).

Constants

HEAD_REF_NAMES
Names of references (“branches”) that are considered to be pointing to the HEAD revision in a VCS, by find_head_rev below. Names are tried in order, when attempting to identify the HEAD revision.

Functions

find_head_rev
Given a graph and a snapshot node in it, return the node id of the revision pointed by the HEAD branch, if it exists.
find_head_rev_by_refs
Same as find_head_rev, but with the ability to configure which branch names correspond to the HEAD revision.
list_revisions
List revision (commit) nodes in reverse chronological order, in the style of git-rev-list.
list_revisions_with
Variant of list_revisions that allows customizing listing behavior, in particular:
list_root_revisions
Returns all revisions that have no parent revision.